SharePointBodyModel class

Constructors

SharePointBodyModel({String? toMobileNo, String? bussinessId, String? keyword, num? transferAmount})
SharePointBodyModel.fromJson(dynamic json)

Properties

bussinessId → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyword → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toMobileNo → String?
no setter
transferAmount → num?
no setter

Methods

copyWith({String? toMobileNo, String? bussinessId, String? keyword, num? transferAmount}) → SharePointBodyModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited